---
title: <span class="badge object-type-enum"></span> TableCellHeight
---
# <span class="badge object-type-enum"></span> TableCellHeight

Height of a table cell

## Definition

```python
class TableCellHeight(enum.StrEnum):
    """
    Height of a table cell
    """

    SM = "sm"
    MD = "md"
    LG = "lg"
```
